YesStringExtensions extension

Extends String for convenience

on

Properties

isQuoted bool

Available on String, provided by the YesStringExtensions extension

Returns true if first and last char are a double quote (")
no setter

Methods

quote() String

Available on String, provided by the YesStringExtensions extension

Returns a new String wrapped in double quotes or itself if quoted.
unquote() String

Available on String, provided by the YesStringExtensions extension

Returns a new String without outer-quotes or itself if not quoted.