isQuoted property
bool
get
isQuoted
Returns true if first and last char are a double quote (")
Implementation
bool get isQuoted =>
length > 1 && this[0] == "\"" && this[length - 1] == "\"";
Returns true if first and last char are a double quote (")
bool get isQuoted =>
length > 1 && this[0] == "\"" && this[length - 1] == "\"";